"""Add email in user table

Revision ID: 944acee085dd
Revises: 4f016505c7c3
Create Date: 2020-07-28 18:15:44.522287

"""
import sqlalchemy as sa

from alembic import op

# revision identifiers, used by Alembic.
revision = "944acee085dd"
down_revision = "4f016505c7c3"
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "user",
        sa.Column(
            "email",
            sa.String(length=50),
            nullable=False,
            server_default="test@example.com",
        ),
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("user", "email")
    # ### end Alembic commands ###
