import{d as s,r as d,o as n,M as l,c as i,a as o,F as c,b as r,e as m}from"./index-2baeec24.js";const u=m('<div class="modal-dialog"><div class="modal-content"><div class="modal-header"><h5 class="modal-title">Modal title</h5><button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button></div><div class="modal-body"> Woo-hoo, you&#39;re reading this text in a modal! </div><div class="modal-footer"><button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button><button type="button" class="btn btn-primary">Save changes</button></div></div></div>',1),b=[u],_=s({__name:"AboutChore",setup(h){const a=d(null);let t;n(()=>{a.value&&(t=new l(a.value))});function e(){t.show()}return(v,f)=>(r(),i(c,null,[o("button",{type:"button",class:"btn btn-primary",onClick:e}," Launch demo modal 2 "),o("div",{class:"modal fade",tabindex:"-1","aria-hidden":"true",ref_key:"modalRef",ref:a},b,512)],64))}});export{_ as default};
